// IApplicationManager.aidl
package com.ft.possystemapi.server.application;

import android.content.ComponentName;
import com.ft.possystemapi.server.application.InstallResultCallback;
import com.ft.possystemapi.server.application.UnInstallResultCallback;

interface IApplicationManager {
    /**
     * This function implements silent installation of the application
     *
     * @param apkFilePath The absolute path of the application to be installed
     * @param callback application installation interface callback
     */
    void installApplication(String apkFilePath, InstallResultCallback callback);

    /**
     * silent Uninstall application
     *
     * @param packageName
     * @param callback application uninstall interface callback
     */
    void uninstallApplication(String packageName, UnInstallResultCallback callback);

    /**
     * Forbidden uninstall the given pkg application
     *
     * @param pkgName package that forbidden uninstall application
     * @param enabled forbidden or allow uninstall application
     * @return result of operation, true success or false for fail
     */
    boolean forbiddenUninstallApplication(String pkgName, boolean enabled);

    /**
     * Hide the give package application in device
     *
     * @param pkgName application package that will be hided
     * @param hide    hide or show application
     * @return result of operation, true success or false for fail
     */
    boolean hideApplication(String pkgName, boolean hide);

    /**
     * Request to put this application in a mode where the user is locked.
     *
     * @param pkgName The application package name
     * @param enabled if true, the application task will be launched into screen pinning mode.
     *                If false, it will stop the current task from being locked.
     */
    void setApplicationInKioskMode(String pkgName, boolean enabled);

    /**
     * Updates the enabled state for notifications of the given packages
     *
     * @param packages package list that owns the notifications to update
     * @param enabled  whether notifications should be enabled for all apps
     * @return Return set packages Notification enabled result, true success or false fail
     */
    boolean setNotificationsEnabledForAllPackages(in List<String> packages, boolean enabled);

    /**
     * Updates the enabled state for notifications for the given package (and uid).
     * Additionally, this method marks the app importance as locked by the user, which means
     * that notifications from the app will not be considered for showing a blocking helper.
     *
     * @param pkg     package that owns the notifications to update
     * @param enabled whether notifications should be enabled for the app
     * @return Return set package Notification enabled result, true success or false fail
     */
    boolean setNotificationsEnabledForPackage(String pkg, boolean enabled);

    boolean setApplicationSignatureKey(in byte[] appCerBytes);

    /**
     * Clear application data by given pkgName
     *
     * @param pkgName The application which want to be cleared data
     * @return execute result, return true if clear data success.
     */
    boolean clearApplicationData(String pkgName);

    /**
     * Enable or disable App Error Dialog.
     * <p>
     * This method is used in order to not display the crash message when an application crashes.
     *
     * @param enabled True to enable, false to disable.
     */
    void setAppErrorDialogEnabled(boolean enabled);

    /**
    * Whether display application crash message dialog when application crashed.
    */
    boolean getAppErrorDialogEnabled();

    /**
     * Enable or disable App Not Responding Dialog.
     * <p>
     * This method is used in order to not display the crash message when an application not responding.
     *
     * @param enabled True to enable, false to disable.
     */
    void setAppNotRespondingDialogEnabled(boolean enabled);

    /**
    * Whether display application not responding message dialog when application not responding.
    */
    boolean getAppNotRespondingDialogEnabled();

    /**
     * Force stop specified application by given packageName
     *
     * @param pkgName PackageName of application which want to be force stopped.
     */
    void forceStopPackage(String pgkName);

    /**
     * Get application notification is enabled or disabled by given packageName
     *
     * @param packageName Application packageName.
     *
     * @return If true when application notification is enabled or false if notification disabled.
     */
    boolean areNotificationsEnabledForPackage(String packageName);

    /**
     * Judge the application whether in KioskMode by given packageName
     *
     * @param pkgName Specified application packagename
     */
    boolean isApplicationInKioskMode(String pkgName);

    /**
     * Inject application secondary signature certificate.
     * <p>
     * This method is used in order to inject application secondary signature certificate.
     *
     * @param certificate Certificate file byte array.
     * @return The result of certificate injection is true for success and false for failure.
     */
    boolean addAppSignCertificate(in byte[] certificate);

    /**
     * Set an application autorun after device boot compelete.
     *
     * @param pkgName packagename
     * @param clsName classname
     * @param autoRun is autorun
     */
    void setAppAutoRun(String pkgName, String clsName, boolean autoRun);

    /**
     * Check the application whether has been set autorun by packagename.
     *
     * @param pkgName Packagename of application.
     * @return true or false.
     */
    boolean getAppAutoRun(String pkgName);

    /**
     * Check the application is whether in system white list
     *
     * @param pkgName the package name of application
     * @return Return true if the give app has been in system white list.
     */
    boolean getAppInWhitelist(String pkgName);

    /**
     * Set the given application in system white list. Once app has been in system white list,
     * it cannot uninstall, clear userdata and forcestop.
     *
     * @param pkgName the package name of give application
     * @param isTrue true: it should be in system white list, false: not in system white list.
     */
    boolean setAddAppWhitelist(String pkgName, boolean isTrue);

    /**
     * Exit Kiosk Mode directly.
     */
    void stopSystemLockTaskMode();

    /**
     * Sets the given package as the device active admin.
     *
     * @param cn the component name to be registered as device active admin.
     * @return whether the package was successfully registered as the device active admin.
     */
    boolean setActiveAdmin(in ComponentName cn);

    /**
     * Sets the given package as the device owner.
     *
     * @param cn the component name to be registered as device owner.
     * @return whether the package was successfully registered as the device owner.
     */
    boolean setDeviceOwner(in ComponentName cn);

    /**
     * Sets the given component as the profile owner of the given user profile. The package must
     * already be installed. There must not already be a profile owner for this user.
     * Only apps with the MANAGE_PROFILE_AND_DEVICE_OWNERS permission and the shell uid can call
     * this method.
     * Calling this after the setup phase of the specified user has completed is allowed only if:
     * - the caller is SYSTEM_UID.
     * - or the caller is the shell uid, and there are no accounts on the specified user.
     *
     * @param cn the component name to be registered as profile owner.
     * @return whether the component was successfully registered as the profile owner.
     */
    boolean setProfileOwner(in ComponentName cn);

    /**
     * Grant a runtime permission to an application which the application does not
     * already have. The permission must have been requested by the application.
     * If the application is not allowed to hold the permission, a {@link
     * java.lang.SecurityException} is thrown. If the package or permission is
     * invalid, a {@link java.lang.IllegalArgumentException} is thrown.
     * <p>
     * <strong>Note: </strong>Using this API requires holding
     * android.permission.GRANT_RUNTIME_PERMISSIONS and if the user id is
     * not the current user android.permission.INTERACT_ACROSS_USERS_FULL.
     * </p>
     *
     * @param packageName    The package to which to grant the permission.
     * @param permissionName The permission name to grant.
     */
    void grantRuntimePermission(String packageName, String permissionName);

    /**
     * Revoke a runtime permission that was previously granted by {@link
     * #grantRuntimePermission(String, String)}. The
     * permission must have been requested by and granted to the application.
     * If the application is not allowed to hold the permission, a {@link
     * java.lang.SecurityException} is thrown. If the package or permission is
     * invalid, a {@link java.lang.IllegalArgumentException} is thrown.
     * <p>
     * <strong>Note: </strong>Using this API requires holding
     * android.permission.REVOKE_RUNTIME_PERMISSIONS and if the user id is
     * not the current user android.permission.INTERACT_ACROSS_USERS_FULL.
     * </p>
     *
     * @param packageName    The package from which to revoke the permission.
     * @param permissionName The permission name to revoke.
     * @see #grantRuntimePermission(String, String)
     */
    void revokeRuntimePermission(String packageName, String permissionName);

}