// ISystemManager.aidl
package com.ft.possystemapi.server.system;

import com.ft.possystemapi.server.system.DefaultDataChangeResultListener;

// Declare any non-default types here with import statements
interface ISystemManager {

    /**
     * Android OS OTA update
     *
     * @param updatePath ota zip file path
     */
    boolean updateSystem(String updatePath);

    /**
     * Enable/Disable adb status
     * <p>
     * Once the ADB is disabled, no ADB commands should be able to execute.
     * The devices shouldn't be listed in the IDE or through the ADB command (adb devices).
     *
     * @param isTrue true: enable adb; false: disable adb.
     * @return Return 1 if set operation executed success, return other value when set failed.
     */
    int setAdbEnabled(boolean isTrue);

    /**
     * Get adb enabled status of device.
     *
     * @return Return true if adb is enabled, or return false when adb is disabled.
     */
    boolean getAdbEnabled();

    /**
     * Set OTG function disabled/enabled.
     * <p>
     * Once the OTG is disabled, the Pos device should not read any external USB-devices or Flash drives.
     *
     * @param isTrue true: disable OTG; false: enable OTG
     * @return Return 1 when set operation execute success, return 0 if set failed.
     */
    int setOTGDisabled(boolean isTrue);

    /**
     * Get OTG function is disabled or enabled.
     *
     * @return Return true if disabled OTG, or false when OTG is enabled.
     */
    boolean getOTGDisabled();

    /**
     * Enable or disable OTG Storage.
     *
     * @param isTrue True to disable, false to enable.
     */
    int setOTGStorageDisabled(boolean isTrue);

    /**
     * Get OTG Storage function is disabled or enabled.
     *
     * @return Return true if disabled, or false when enabled.
     */
    boolean getOTGStorageDisabled();

    /**
     * Set bluetooth disabled/enabled.
     * <p>
     * Once the bluetooth is disabled, it should close bluetooth connection.
     * Should we need to:
     * <p>
     * a)close the bluetooth;
     * <p>
     * b)the setting menu will hide the bluetooth menu, can be hide or disable (read only);
     * <p>
     * c)hide the option option in the android Drop-down menu.
     * <p>
     * Once the bluetooth is enabled, it should work as normal.
     *
     * @param isTrue true: disable bluetooth; false: enable bluetooth.
     * @return Return 1 if set BT operation executed success, or return other values when set failed.
     */
    int setBluetoothDisabled(boolean isTrue);

    /**
     * Get Bluetooth function is disabled or enabled.
     *
     * @return Return true if BT is disabled, return false when BT is enabled.
     */
    boolean getBluetoothDisabled();

    /**
     * Enable or disable BT Transfer File.
     *
     * @param isTrue True to disable, false to enable.
     */
    int setBTTransferFileDisabled(boolean isTrue);

    /**
     * Get BT Transfer File function is disabled or enabled.
     *
     * @return Return true if disabled, return false when enabled.
     */
    boolean getBTTransferFileDisabled();

    /**
     * Set WIFI function disabled/enabled
     * <p>
     * Once the WIFI is enabled, it should work as normal
     * Once the WIFI is disabled, it should close WIFI connection.
     * <p>
     * a)close the wifi;
     * <p>
     * b)the setting menu will hide the wifi menu, can be hide or disable (read only);
     * <p>
     * c)hide the wifi option in the android Drop-down menu.
     *
     * @param isTrue true: disable WIFI; false: enable WIFI
     * @return Return 1 when set operation execute success, return 0 if set failed.
     */
    int setWifiDisabled(boolean isTrue);

    /**
     * Get WIFI function is disabled or enabled of device.
     *
     * @return Return true if WIFI is disabled, else return false.
     */
    boolean getWifiDisabled();

    /**
     * Set navBar disabled. We can use this to Enable/ Disable Home/Recent/Back Button.
     *
     * @param flag Integer flags for disable navbar button. The flag can be:
     *             <p>
     *             public static final int DISABLE_NONE = 0x00000000; // Reset navbar buttons.
     *             <p>
     *             public static final int DISABLE_RECENT = 0x01000000;
     *             <p>
     *             public static final int DISABLE_HOME = 0x00200000;
     *             <p>
     *             public static final int DISABLE_BACK = 0x00400000;
     *             <p>
     *             public static final int DISABLE_ALL = DISABLE_RECENT|DISABLE_HOME|DISABLE_BACK;
     * @return Return 1 if set operation success, or return other values when set failed.
     */
    int setNavBarDisabled(int flag);

    /**
     * Get navbar button(like RECENTS/HOME/BACK) disabled status.
     *
     * @return navBarDisabled Which NavBar button was disabled. The flag can be:
     * <p>
     * public static final int DISABLE_NONE = 0x00000000;
     * <p>
     * public static final int DISABLE_RECENT = 0x01000000;
     * <p>
     * public static final int DISABLE_HOME = 0x00200000;
     * <p>
     * public static final int DISABLE_BACK = 0x00400000;
     */
    int getNavBarDisabled();

    /**
     * Set PowerKey disabled/enabled
     * <p>
     * Once the power button is enabled, it should work as normal.
     * Once the power button is disabled, it should do nothing on pressed.
     * <p>
     * We are disabling the power button during the transaction so that even accidentally pressed,
     * it wouldn't affect the on-going transaction process.
     *
     * @param isTrue true: disable PowerKey; false: enable PowerKey
     * @return Return 1 when set operation execute success, return 0 if set failed.
     */
    int setPowerKeyDisabled(boolean isTrue);

    /**
     * Get power key whether disabled or not.
     *
     * @return Return true if power key is disabled, else return false.
     */
    boolean getPowerKeyDisabled();

    /**
     * Get current system time of device, return a UTC format time string.
     *
     * @return UTC String format of current system time, like: "2021-03-18T06:03:02.634Z"
     */
    String getSystemCurrentTime();

    /**
     * Set current system time by give time information string.
     *
     * @param timeInfo UTC format time string, like: "2021-03-18T06:03:02.634Z", or "2021-03-03T19:17:38Z"
     * @return Return 1 when set operation execute success, return 0 if set failed.
     */
    int setSystemCurrentTime(String timeInfo);

    /**
     * Set Micro SDCard disabled/enabled.
     *
     * @param isTrue true: disable Micro SDCard; false: enable Micro SDCard
     * @return Return 1 when set operation execute success, or return 0 if set failed.
     */
    int setMicroSDDisabled(boolean isTrue);

    /**
     * Get Micro SDCard status is disabled or enabled.
     *
     * @return Return true if Micro SDCard is disabled, or false when Micro SDCard is enabled.
     */
    boolean getMicroSDDisabled();

    /**
     * This method changes the requested password to enter Android system settings;
     * To disable the password requested to enter Android system settings.
     *
     * @param pwd    password for enter settings
     * @param isTrue enable/disable password
     */
    boolean setSettingsPassword(String pwd, boolean isTrue);

    /**
     * Get enter Android system settings password
     *
     * @return return password for enter settings, or return null if not set password.
     */
    String getSettingsPassword();

    /**
     * Get Airplane Mode is enabled or disabled.
     */
    boolean getAirplaneDisabled();

    /**
     * Enable or disable Airplane Mode.
     *
     * @param disable True to disable, false to enable.
     */
    void setAirplaneDisabled(boolean disable);

    /**
     * Get Daydream is enabled or disabled.
     */
    boolean getDaydreamEnabled();

    /**
     * Enable or disable Daydream.
     *
     * @param enabled True to enable, false to disable.
     */
    void setDaydreamEnabled(boolean enabled);

    /**
     * Set Daydream Active.
     *
     * @param packageName Daydream package name.
     */
    boolean setDaydreamActive(String packageName);

    /**
     * Set Daydream mode.
     *
     * @param daydreamMode Daydream configuration menu: DOCK, SLEEP, EITHER, ALWAYS.
     */
    void setDaydreamMode(String daydreamMode);

    /**
     * Enable or disable File Manager.
     *
     * @param enabled True to enable, false to disable.
     */
    void setFileManagerEnabled(boolean enabled);

    /**
     * Get File Manager is enabled or disabled.
     */
    boolean getFileManagerEnabled();

    /**
     * Get Wi-Fi & Hotspot is enabled or disabled.
     */
    boolean getWifiHotspotDisabled();

    /**
     * Enable or disable Wi-Fi & Hotspot.
     *
     * @param disabled True to disable, false to enable.
     */
    boolean setWifiHotspotDisabled(boolean disabled);

    /**
     * Get Accessibility is enabled or disabled.
     */
    boolean getAccessibilityDisabled();

    /**
     * Enable or disable Accessibility.
     *
     * @param disabled True to disable, false to enable.
     */
    boolean setAccessibilityDisabled(boolean disabled);

    /**
     * Get Account is enabled or disabled.
     */
    boolean getAccountDisabled();

    /**
     * Enable or disable Account.
     *
     * @param disabled True to disable, false to enable.
     */
    boolean setAccountDisabled(boolean disabled);

    /**
     * Get default font scale size of system.
     */
    float getAppDefaultFont();

    /**
     * Set default font scale size
     *
     * @param fontSize font scale of system default.
     */
    boolean setAppDefaultFont(float fontSize);

    /**
     * Get battery percent is show or hide in statusbar.
     */
    boolean getBatteryPercentageEnabled();

    /**
     * Show or hide battery percent.
     *
     * @param show True to display, false to hide.
     */
    boolean setBatteryPercentageEnabled(boolean show);

    /**
     * Set default language of device system
     *
     * @param language The language code, or the empty string if none is defined, e.g. "en", "zh"
     * @param country  The country/region code for this locale, which should
     *                 either be the empty string, an uppercase ISO 3166 2-letter code,
     *                 or a UN M.49 3-digit code, e.g. "CN", "US"
     */
    boolean setDefaultLanguage(String language, String country);

    /**
     * Set system time format 24hour or 12hour
     *
     * @param is24Hour true: 24hour, false: 12hour
     */
    void setDefaultTimeFormat(boolean is24Hour);

    /**
     * Set device default timezone
     *
     * @param zoneId e.g: "Asia/Shanghai"
     */
    void setDefaultTimeZone(String zoneId);

    /**
     * Double tap button behavior.
     *
     * @param button Navigation button. Back, home or menu button.
     * @param action Button behavior (such as launch camera).
     */
    void setDoubleTapButtonAction(String button, String action);

    /**
     * Set a list of locales for device default
     *
     * @param locales LocaleList
     */
    boolean setLocales(in LocaleList locales);

    /**
     * Long tap button behavior.
     *
     * @param button Navigation button. Back, home or menu button.
     * @param action Button behavior (such as launch camera).
     */
    void setLongTapButtonAction(String button, String action);

    /**
     * Get connected to UnauthorizedWifi is enabled or disabled.
     */
    boolean getUnauthorizedWifiDisabled();

    /**
     * Enable or disable connected to Unauthorized Wifi.
     *
     * @param disabled True to disable, false to enable.
     */
    void setUnauthorizedWifiDisabled(boolean disabled);

    /**
     * Get Location is enabled or disabled.
     */
    boolean getLocationDisabled();

    /**
     * Enable or disable Location.
     *
     * @param disabled True to disable, false to enable.
     */
    boolean setLocationDisabled(boolean disabled);

    /**
     * Set the default TTS application.
     *
     * @param engine Speech application name.
     */
    void setPreferredTTSEngine(String engine);

    /**
     * Get StatusBar is enabled or disabled.
     */
    boolean getStatusBarEnabled();

    /**
     * Enable or disable the status bar.
     *
     * @param enabled True to enable, false to disable.
     */
    void setStatusBarEnabled(boolean enabled);

    /**
     * Get system default timezone.
     */
    String getDefaultTimeZone();

    /**
     * Get system default language.
     */
    String getDefaultLanguage();

    /**
     * Returns true if location is enabled in settings.
     */
    boolean isLocationEnabled();

    /**
     * Enable or disable location in settings.
     *
     * <p>This will attempt to enable/disable every type of location setting
     * (e.g. high and balanced power).
     *
     * <p>If enabling, a user consent dialog will pop up prompting the user to accept.
     * If the user doesn't accept, network location won't be enabled.
     *
     * @return true if attempt to change setting was successful.
     */
    boolean setLocationEnabled(boolean enabled);

    /**
     * This method changes the requested password to enter Android system settings;
     * To disable the password requested to enter Android system settings
     *
     * @param pwd the second password for enter settings
     * @param enabled enable/disable second password
     */
    boolean setSettingsSecondPassword(String pwd, boolean enabled);

    /**
     * Get the second password for enter Android system settings
     *
     * @return second password for enter settings, or return null if not set password.
     */
    String getSettingsSecondPassword();

    /**
     * Set system date
     *
     * @param year  The year.
     * @param month [1~12] The first month of the year in the Gregorian and Julian calendars is JANUARY which is 0.
     * @param day   The day of the month. The first day of the month has value 1.
     */
    void setDate(int year, int month, int day);

    /**
     * Set system time
     *
     * @param hourOfDay The hour of the day. HOUR_OF_DAY is used for the 24-hour clock.
     *                  E.g., at 10:04:15.250 PM the HOUR_OF_DAY is 22.
     * @param minute    The minute within the hour. E.g., at 10:04:15.250 PM the MINUTE is 4.
     * @param second    The second within the minute.
     *                  E.g., at 10:04:15.250 PM the SECOND is 15.
     */
    void setTime(int hourOfDay, int minute, int second);

    /**
     * Set system date and time together
     *
     * @param year      The year
     * @param month     [1~12] The first month of the year in the Gregorian and Julian calendars is JANUARY which is 0.
     * @param day       The day of the month
     * @param hourOfDay The hour of the day. HOUR_OF_DAY is used for the 24-hour clock.
     *                  E.g., at 10:04:15.250 PM the HOUR_OF_DAY is 22.
     * @param minute    The minute within the hour. E.g., at 10:04:15.250 PM the MINUTE is 4.
     * @param second    The second within the minute.
     *                  E.g., at 10:04:15.250 PM the SECOND is 15.
     */
    void setDateTime(int year, int month, int day, int hourOfDay, int minute, int second);

    /**
     * Judge the given application is Gertec custom Verified Factory apps or not.
     *
     * @param packageName The given application package name
     * @return Return true if is verified Factory app, or return false if not.
     */
    boolean isGertecVerifiedFactoryApp(String packageName);

    /**
     * Judge the given application is Gertec custom Verified Enhanced apps or not.
     *
     * @param packageName The given application package name
     * @return Return true if is verified Enhanced app, or return false if not.
     */
    boolean isGertecVerifiedEnhancedApp(String packageName);

    /**
     * Judge the given application is Gertec custom Verified Customer apps or not.
     *
     * @param packageName The given application package name
     * @return Return true if is verified Customer app, or return false if not.
     */
    boolean isGertecVerifiedCustomerApp(String packageName);

    /**
     * Set Gertec custom Factory Certificate Key
     *
     * @param keyPath The file path of Certificate.
     */
    void setFactoryKey(String keyPath);

    /**
     * Set Gertec custom Enhanced Certificate Key
     *
     * @param keyPath The file path of Certificate.
     */
    void setEnhancedKey(String keyPath);

    /**
     * Set Gertec custom Customer Certificate Key
     *
     * @param keyPath The file path of Certificate.
     */
    void setCustomerKey(String keyPath);

    byte[] readFile(String filePath);

    /**
     * Set the subscription which will be used by default for data,
     * with the subscription which the supplied slot index corresponds to
     *
     * @param slotIndex the slot index.
     */
    boolean setDefaultDataSim(int slotIndex);

    boolean isMobileDataEnabled();

    /**
     * Turns mobile data on or off.
     * If this object has been created with createForSubscriptionId, applies to the given
     * subId. Otherwise, applies to {@link SubscriptionManager#getDefaultDataSubscriptionId()}
     *
     * <p>Requires Permission:
     * {@link android.Manifest.permission#MODIFY_PHONE_STATE MODIFY_PHONE_STATE} or that the calling
     * app has carrier privileges.
     *
     * @param enabled Whether to enable mobile data.
     */
    void setMobileDataEnabled(boolean enabled);

    void setDeviceDefaultDataSim(int slotIndex, DefaultDataChangeResultListener listener, long switchTimeout);

    /**
     * Open or close WIFI
     *
     * @param on true for Open, false for close
     */
    void turnOnWifi(boolean on);

    /**
     * Open or close Bluetooth
     *
     * @param on true for Open, false for close
     */
    void turnOnBluetooth(boolean on);

    /**
     * Open or close Location
     *
     * @param on true for Open, false for close
     */
    void turnOnLocation(boolean on);

    /**
     * Open or close Airplane Mode
     *
     * @param on true for Open, false for close
     */
    void turnOnAirplane(boolean on);

    /**
     * Open or close Hotspot
     *
     * @param on true for Open, false for close
     */
    void turnOnHotspot(boolean on);

    /**
     * Open or close Flashlight
     *
     * @param on true for Open, false for close
     */
    void turnOnFlashlight(boolean on);

    /**
     * Open or close PowerSave mode
     *
     * @param on true for Open, false for close
     */
    void turnOnPowerSave(boolean on);

    /**
     * Hide or show VolumeDialog SettingsView of SystemUI
     *
     * @param isDisable True for hide, false for show.
     */
    boolean setVolumeSettingsDisabled(boolean isDisable);

    /**
     * Get whether or not hide VolumeDialog SettingsView of SystemUI
     *
     * @return True if hide, false for show.
     */
    boolean getVolumeSettingsDisabled();

    /**
     * Save specified file to persist disk, max file length is 2KB
     *
     * @param sourceFilePath File path of Source file
     * @param targetFileName The file name will be saved in target directory of Source file
     */
     boolean persistSaveCustomerFile(String sourceFilePath, String targetFileName);

    /**
     * Read specified file of saved to persist disk
     *
     * @param fileName The file name saved in specified persist directory
     */
     byte[] readPersistSaveCustomerFile(String fileName);

    /**
     * Delete specified file which has been saved to persist disk
     *
     * @param fileName The file name saved in specified persist directory
     */
     boolean deletePersistSaveCustomerFile(String fileName);

}